#
# spec file for package python-IMAPClient
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2016-2019 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-IMAPClient
Version:        2.3.1
Release:        2.5
Summary:        Pythonic IMAP client library
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/mjs/imapclient/
Source0:        https://github.com/mjs/imapclient/archive/%{version}.tar.gz
# https://github.com/mjs/imapclient/commit/6e6ec34b0e71975134d9492add22361ce4beb2a0
Patch0:         python-IMAPClient-no-python2.patch
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools >= 20.5}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
IMAPClient is a Pythonic IMAP client library.

Features:
    * Arguments and return values are natural Python types.
    * IMAP server responses are parsed and readily usable.
    * IMAP unique message IDs (UIDs) and internationalised
      mailbox names are handled transparently.
    * Time zones are handled.
    * Convenience methods are provided for commonly used functionality.
    * Exceptions are raised when errors occur.

IMAPClient includes comprehensive units tests and automated
functional tests that can be run against a live IMAP server.

%prep
%setup -q -n imapclient-%{version}
%patch0 -p1

%build
sed -i 's:#!::' imapclient/interact.py
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_redacted_password fails on openSUSE 15.x only
%pytest -k 'not test_redacted_password'

%files %{python_files}
%doc README.rst
%license COPYING
%{python_sitelib}/IMAPClient-*-info
%{python_sitelib}/imapclient

%changelog
* Mon Nov  7 2022 pgajdos@suse.com
- do not require six for build
- added patches
  fix https://github.com/mjs/imapclient/commit/6e6ec34b0e71975134d9492add22361ce4beb2a0
  + python-IMAPClient-no-python2.patch
* Tue Aug  2 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to 2.3.1
  Changed
  - ------
  - Use GitHub Actions instead of TravisCI
  - Improvements to code examples
  - Run tests with unittest instead of setup.py
  Added
  - ----
  - New socket() method which provides access to the underlying network socket. This is useful for allowing the socket to be polled.
  - Allow flags and internaldate to be specified for MULTIAPPEND
  Fixed
  - ----
  - Default SSL contexts are now created with correct purpose
  - Fixed undiscoverable tests due to name shadowing
  - Fixed missing code block directives in documentation
  - Fixed typo in tox envlist
  - Fixed formatting in release notes
* Mon Mar 21 2022 pgajdos@suse.com
- python-mock is actually not required for build
* Thu Aug 26 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.2.0:
  Changed
  - ------
  - Performance improvements (thanks Carson Ip!)
  - 2x faster _maybe_int_to_bytes for Python 2 (#375)
  - Fix _proc_folder_list quadratic runtime (#374)
  - Faster utf7 encode (#373). ~40%% faster for input with a mix of unicode and
    ASCII chars.
  - Cache regex in _process_select_response
  - poll() when available to surpass 1024 file descriptor limit with select()
    (#377) (thanks Jonny Hatch)
  - Use next instead of six.next as imapclient doesn't claim Python 2.5 support.
    (#396) (thanks Jasper Spaans)
  - Moved "Logged in/out" traces from INFO to DEBUG level (thanks Fabio Manganiello)
  - Run tests on Python 3.8 and 3.9
  - Support the Deleted special folder used by Outlook (thanks Samir M)
  - Clean up timeout handling
  - Run the Black code formatter over the entire project
  Added
  - ----
  - MULTIAPPEND and LITERAL+ support (#399) (thanks Devin Bayer)
  - Use ptpython for interactive shell if available (#272)
  - Allow any custom SASL mechanism to be provided. This allows mechanisms such
    as EXTERNAL, GSSAPI or SCRAM-SHA-256 to be used in the same way as with
    imaplib. (thanks Mantas Mikulėnas)
  - Add SASL OAUTHBEARER support
  - add optional timeout parameter to IMAP4_TLS.open (thanks zrose584)
  Fixed
  - ----
  - fixed special folder searching
  - Catch the right exception in folder_status (#371)
  - test_imapclient: Fix LoggerAdapter version check
    (#383) (thanks Michał Górny)
  - Fix config file parsing for None attributes
    (#393) (thanks François Deppierraz)
  - Fix useless ref cycle in lexer
  - Protocol parsing: Prevent converting numbers with leading zeroes to int.
    (#390) (#405) (thanks Jasper Spaans)
  - Prevent UnicodeDecodeError in IMAPlibLoggerAdapter (#367)
  - Fix invalid string escape sequences (#397)
  - Ensure timeout is used on Python 2.7.  _create_socket isn't used with the
    Python 2 version of imaplib so the open method has been overrided to make it
    consistent across Python version (#380).
  - Fix IMAP4_TLS for imaplib in Python 3.9+
    (thanks Christopher Arndt, marmarek and link2xt)
* Mon Jun  8 2020 Jan Engelhardt <jengelh@inai.de>
- Trim bias and filler wording from descriptions.
* Sun Jun  7 2020 John Vandenberg <jayvdb@gmail.com>
- Tidy spec
- Activate test suite
* Wed Mar  6 2019 Hans-Peter Jansen <hpj@urpla.net>
- update to 2.1.0:
  too many changes to list here, check github
- python single spec
* Mon Dec 12 2016 hpj@urpla.net
- add runtime requirements
* Mon Dec 12 2016 hpj@urpla.net
- remove backports.ssl tarball
* Fri Nov 18 2016 boris@steki.net
- initial packaging
